cylouvain
=========

cylouvain is a Python module that provides a fast implementation
of the classic Louvain algorithm for community detection in graphs.
This module uses Cython in order to give C-like performance with
code mostly writen in Python.